\name{polychor}
\alias{polychor}

\title{Polychoric Correlation}
\description{
  Computes the polychoric correlation between two ordinal variables or from their contingency table, under the 
  assumption that the ordinal variables dissect continuous latent variables that are bivariate normal. Either
  the maximum-likelihood estimator or a (possibly much) quicker ``two-step'' approximation are available. For the ML
  estimator the estimates of the thresholds and the covariance matrix of the estimates are also available.
}

\usage{
polychor(x, y, ML = FALSE, control = list(), std.err = FALSE)
}

\arguments{
  \item{x}{a contingency table of counts or an ordered categorical variable; the latter can be numeric, a factor,
    or an ordered factor, but if a factor, its levels should be in proper order.}
  \item{y}{if \code{x} is a variable, a second ordered categorical variable.}
  \item{ML}{if \code{TRUE}, compute the maximum-likelihood estimate; if \code{FALSE}, the default, compute a quicker
    ``two-step'' approximation.}
  \item{control}{optional arguments to be passed to the \code{optim} function, which computes the ML estimate;
    for \code{ML=TRUE} only.}
  \item{std.err}{if \code{TRUE}, return the estimated covariance matrix of the correlation and
    thresholds; used only if \code{ML=TRUE}; the default is \code{FALSE}.}
}

\value{
  If \code{ML} and \code{std.err} are both \code{TRUE}, 
  returns an object of class \code{"polycor"} with the following components:
  \item{type}{set to \code{"polychoric"}.}
  \item{rho}{the polychoric correlation.}
  \item{row.cuts}{estimated thresholds for the row variable (\code{x}).}
  \item{col.cuts}{estimated thresholds for the column variable (\code{y}).}
  \item{var}{the estimated covariance matrix of the correlation and thresholds.}
  \item{n}{the number of observations on which the correlation is based.}
  Othewise, returns the polychoric correlation.
}

\references{
    Drasgow, F. (1986) 
    Polychoric and polyserial correlations. 
    Pp. 68--74 in S. Kotz and N. Johnson, eds.,
    \emph{The Encyclopedia of Statistics, Volume 7.} Wiley.
    
    Olsson, U. (1979)
    Maximum likelihood estimation of the polychoric correlation coefficient.
    \emph{Psychometrika} \bold{44}, 443-460.
}

\author{John Fox \email{jfox@mcmaster.ca}}

\seealso{\code{\link{hetcor}}, \code{\link{polyserial}}, \code{\link{print.polycor}},
  \code{\link[stats]{optim}}}

\examples{
data <- rmvnorm(1000, c(0, 0), matrix(c(1, .5, .5, 1), 2, 2))
x <- data[,1]
y <- data[,2]
cor(x, y)  # sample correlation
x <- cut(x, c(-Inf, .75, Inf))
y <- cut(y, c(-Inf, -1, .5, 1.5, Inf))
polychor(x, y)  # 2-step estimate
polychor(x, y, ML=TRUE, std.err=TRUE)  # ML estimate
}

\keyword{models}
